@@ -7,6 +7,7 @@
 #include <stdio.h>
 #include <limits.h>
 #include <string.h>
+#include <locale.h>
 
 #define IN_CRACKLIB
 #include "config.h"
@@ -20,6 +21,9 @@ main(int argc, char **argv)
 	const char *why;
 	int i;
 
+	setlocale(LC_ALL, "");
+	textdomain(PACKAGE);
+
 	while (fgets(buf, sizeof(buf), stdin) != NULL) {
 		while (((i = strlen(buf)) > 0) && (i > 0)) {
 			if (strchr("\r\n", buf[i - 1]) != NULL) {
